/*******************************************************************************
* File Name: PWM_Window_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PWM_Window.h"

static PWM_Window_backupStruct PWM_Window_backup;


/*******************************************************************************
* Function Name: PWM_Window_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Window_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_Window_SaveConfig(void)
{
    
    #if(!PWM_Window_UsingFixedFunction)
        #if (PWM_Window_PSOC3_ES2 || PWM_Window_PSOC5_ES1)
            PWM_Window_backup.PWMUdb = PWM_Window_ReadCounter();
            PWM_Window_backup.PWMPeriod = PWM_Window_ReadPeriod();
            #if (PWM_Window_UseStatus)
                PWM_Window_backup.InterruptMaskValue = PWM_Window_STATUS_MASK;
            #endif
            
            #if(PWM_Window_UseOneCompareMode)
                PWM_Window_backup.PWMCompareValue = PWM_Window_ReadCompare();
            #else
                PWM_Window_backup.PWMCompareValue1 = PWM_Window_ReadCompare1();
                PWM_Window_backup.PWMCompareValue2 = PWM_Window_ReadCompare2();
            #endif
            
           #if(PWM_Window_DeadBandUsed)
                PWM_Window_backup.PWMdeadBandValue = PWM_Window_ReadDeadTime();
            #endif
          
            #if ( PWM_Window_KillModeMinTime)
                PWM_Window_backup.PWMKillCounterPeriod = PWM_Window_ReadKillTime();
            #endif
        #endif
        
        #if (PWM_Window_PSOC3_ES3 || PWM_Window_PSOC5_ES2)
            #if(!PWM_Window_PWMModeIsCenterAligned)
                PWM_Window_backup.PWMPeriod = PWM_Window_ReadPeriod();
            #endif
            PWM_Window_backup.PWMUdb = PWM_Window_ReadCounter();
            #if (PWM_Window_UseStatus)
                PWM_Window_backup.InterruptMaskValue = PWM_Window_STATUS_MASK;
            #endif
            
            #if(PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_256_CLOCKS || PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_2_4_CLOCKS)
                PWM_Window_backup.PWMdeadBandValue = PWM_Window_ReadDeadTime();
            #endif
            
            #if(PWM_Window_KillModeMinTime)
                 PWM_Window_backup.PWMKillCounterPeriod = PWM_Window_ReadKillTime();
            #endif
        #endif
        
        #if(PWM_Window_UseControl)
            PWM_Window_backup.PWMControlRegister = PWM_Window_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: PWM_Window_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Window_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void PWM_Window_RestoreConfig(void) 
{
        #if(!PWM_Window_UsingFixedFunction)
            #if (PWM_Window_PSOC3_ES2 || PWM_Window_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 PWM_Window_interruptState;
                /* Enter Critical Region*/
                PWM_Window_interruptState = CyEnterCriticalSection();
                #if (PWM_Window_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    PWM_Window_STATUS_AUX_CTRL |= PWM_Window_STATUS_ACTL_INT_EN_MASK;
                    
                    PWM_Window_STATUS_MASK = PWM_Window_backup.InterruptMaskValue;
                #endif
                
                #if (PWM_Window_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    PWM_Window_AUX_CONTROLDP0 |= (PWM_Window_AUX_CTRL_FIFO0_CLR);
                #else /* (PWM_Window_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    PWM_Window_AUX_CONTROLDP0 |= (PWM_Window_AUX_CTRL_FIFO0_CLR);
                    PWM_Window_AUX_CONTROLDP1 |= (PWM_Window_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(PWM_Window_interruptState);
                
                PWM_Window_WriteCounter(PWM_Window_backup.PWMUdb);
                PWM_Window_WritePeriod(PWM_Window_backup.PWMPeriod);
                
                #if(PWM_Window_UseOneCompareMode)
                    PWM_Window_WriteCompare(PWM_Window_backup.PWMCompareValue);
                #else
                    PWM_Window_WriteCompare1(PWM_Window_backup.PWMCompareValue1);
                    PWM_Window_WriteCompare2(PWM_Window_backup.PWMCompareValue2);
                #endif
                
               #if(PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_256_CLOCKS || PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_2_4_CLOCKS)
                    PWM_Window_WriteDeadTime(PWM_Window_backup.PWMdeadBandValue);
                #endif
            
                #if ( PWM_Window_KillModeMinTime)
                    PWM_Window_WriteKillTime(PWM_Window_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (PWM_Window_PSOC3_ES3 || PWM_Window_PSOC5_ES2)
                #if(!PWM_Window_PWMModeIsCenterAligned)
                    PWM_Window_WritePeriod(PWM_Window_backup.PWMPeriod);
                #endif
                PWM_Window_WriteCounter(PWM_Window_backup.PWMUdb);
                #if (PWM_Window_UseStatus)
                    PWM_Window_STATUS_MASK = PWM_Window_backup.InterruptMaskValue;
                #endif
                
                #if(PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_256_CLOCKS || PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_2_4_CLOCKS)
                    PWM_Window_WriteDeadTime(PWM_Window_backup.PWMdeadBandValue);
                #endif
                
                #if(PWM_Window_KillModeMinTime)
                    PWM_Window_WriteKillTime(PWM_Window_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(PWM_Window_UseControl)
                PWM_Window_WriteControlRegister(PWM_Window_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: PWM_Window_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Window_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_Window_Sleep(void)
{
    #if(PWM_Window_UseControl)
        if(PWM_Window_CTRL_ENABLE == (PWM_Window_CONTROL & PWM_Window_CTRL_ENABLE))
        {
            /*Component is enabled */
            PWM_Window_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PWM_Window_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    PWM_Window_Stop();
    
    /* Save registers configuration */
    PWM_Window_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_Window_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Window_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void PWM_Window_Wakeup(void) 
{
     /* Restore registers values */
    PWM_Window_RestoreConfig();
    
    if(PWM_Window_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PWM_Window_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
