/* --------------------------------------------------------------------------
* Copyright 2010, Cypress Semiconductor Corporation.
*
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international
* treaty provisions. Cypress hereby grants to licensee a personal,
* non-exclusive, non-transferable license to copy, use, modify, create
* derivative works of, and compile the Cypress Source Code and derivative
* works for the sole purpose of creating custom software in support of
* licensee product to be used only in conjunction with a Cypress integrated
* circuit as specified in the applicable agreement. Any reproduction,
* modification, translation, compilation, or representation of this
* software except as specified above is prohibited without the express
* written permission of Cypress.
* 
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED,
* WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising
* out of the application or use of any product or circuit described herein.
* Cypress does not authorize its products for use as critical components in
* life-support systems where a malfunction or failure may reasonably be
* expected to result in significant injury to the user. The inclusion of
* Cypress' product in a life-support systems application implies that the
* manufacturer assumes all risk of such use and in doing so indemnifies
* Cypress against all charges.
* 
* Use may be limited by and subject to the applicable Cypress software
* license agreement.
* -----------------------------------------------------------------------------
* Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
*
*****************************************************************************
*  Project Name: Counter_FreqMeasurement  
*  Project Revision: 1.00
*  Device Tested: CY8C3866AXI, CY8C5588AXI
*  Software Version: PSoC Creator Beta 5.0
*  Complier tested: Keil(C51) and GCC
*  Related Hardware: CY8CKIT-001
*****************************************************************************
***************************************************************************** */

/* 
* Description:
* =============
* The project aims at using the Counter to do a High Frequency measurement.
* Operation of Project:
* =====================
* The input signal whose frequency is to be measured is given to the "Count" input of the
* Counter. The Counter captures the count whenever a rising edge occurs at the capture.
* The capture signal is generated by a PWM (PWM_Window). The PWM clock configured is 100 KHz in the example. 
* So the PWM Output (configured for period of 9999 and compare value of 4999 and compare type of less than or equal)
* generates a high level for 50 ms. This is the period during which the counter would capture.
* The counter counts during a single period of PWM Output (i.e.) 100 milliseconds.
* The counts captured during the 100 millisecond is used to calculate the frequency of the signal.
* The calculated frequency is converted to HZ and displayed on the LCD
* The project works from 20 Hz to 8 MHz. The lower limit is imposed because of the capture signal which is
* 50 ms. The minimum frequency to capture will be 1/50 ms = 20 Hz. The maximum frequency limit is imposed
* by the system clock. 
* Components used:
* ================
* Counter block:
* Resolution -> 32 bit
* Period -> 0xFFFFFFFF
* Count direction -> Up counter
* Reload on Capture --> True
* Reload on Reset --> True
* PWM block:
* Resolution -> 16 bit
* Period -> 9999 (to get 100.00 millisecond period)
* Interrupt on CompareEvent1 --> True
* Number of Outputs --> 1
* Compare value --> 4999 (to get a Capture signal for 2 PWM clocks)
* Compare type --> Less than or Equal
* Digital Input pin: 
* Mapped to P0[2]
* Driver mode: Hi_Z
* Character LCD
* Hardware connections:
* =====================
* Connect the output from function generator to the P0[2]
* The Character LCD module should be connected to the DVK
********************************************************************************************/

#include <device.h>
#include <stdio.h>

/* These variables are accessed in the ISRs 
 * Accessed in ISR_Compare to update the counter value */
//extern uint8 compare_occured;

/* The clock frequency for the PWM_Window. The PWM_Window clock frequency must be in KHz. 
 * Please update this define if the clock is updated in the TopDesign */
#define PWM_FREQ 10 //10kHz

/* Define for 1 second in terms of millisecond */
#define NO_OF_MSEC 1000
#define forever 1 // I just like this

char Buffer[16];	// Display buffer
static uint16 PWM_windowPeriod = 0;		/* Variables to store the Period of the PWM_Window */

void InitializeHardware(void)
{
	//Comp_Start();
//	ISR_Compare_Start();
	PWM_Window_Start();
	Counter_Start();
	LCD_Display_Start();
	Clock_PWM_Start();

	
	/* Calculate the time window during which the counter will count */
	PWM_windowPeriod = PWM_Window_ReadPeriod() ;
	
	/* Update the Time window value according to the clock given to the PWM_Window */
	//PWM_windowPeriod = PWM_windowPeriod/ PWM_FREQ; 

	/* Enable the global interrupt */
	CYGlobalIntEnable;
}

/*
// I usually tend to write 
void PrintFrequency(uint32 Frequency)
{
char Buffer[16];
	LCD_Display_Position(1, 0);
	sprintf(Buffer,"%ld",Frequency);
	LCD_Display_PrintString(Buffer);
}
*/

void main()
{
uint32 input_freq = 0;	
static uint32 counter_countVal;			/* Variable to store the count value after capture */

	InitializeHardware();

	/* Display the term PULSE COUNT/SEC on line 1 of the LCD */
	//LCD_Display_Position(0, 0);
	//LCD_Display_PrintString("PULSE COUNT/SEC");			
	
	while(forever)
    {
		// Check if a value has been captured
		if (Counter_ReadStatusRegister() & Counter_STATUS_FIFONEMP)
		{
			/* Read the Counter register */
//			counter_countVal = Counter_ReadCounter(); ***** This is wrong!! Look at the API in the datasheet ******
			counter_countVal = Counter_ReadCapture(); // This is what we want, a captured value
			
			/* Convert the counts to frequency.
			 * Frequency is the number of counts in seconds
			 * In this case counts within "PWM time window" (100 millisecond in this example) is got from Counter. 
			 * So we need to find for 1000 milliseconds */
			/* input_freq = ((uint32)(NO_OF_MSEC * (uint32)counter_countVal) / (uint32)PWM_windowPeriod); 
			
			

			/* Display the value in the LCD */
			
			LCD_Display_ClearDisplay();
			LCD_Display_Position(0, 0);
			LCD_Display_PrintString("PULSE COUNT/SEC");			
			
			LCD_Display_Position(1, 0);
//			LCD_Display_PrintInt16(counter_countVal); // counter_countVal is a uint32, will not work  

			sprintf(Buffer,"%ld",counter_countVal);
			LCD_Display_PrintString(Buffer);
			
			// Or just
			//PrintFrequency(counter_countVal);
			// Whatever you like more
			/*LCD_Display_Position(1, 0);
			LCD_Display_PrintInt16(HI16(counter_countVal)); 
					
			/*LCD_Display_Position(1, 4);
			LCD_Display_PrintInt16(LO16(counter_countVal)); 
			LCD_Display_Position(1, 9);
			LCD_Display_PrintString("Hz");				
			
			/* Clear the interrupt flag */
//			compare_occured = 0; not needed
		}
    }
}

/* [] END OF FILE */